Create reports — SLiCAP 3.5.7 documentation

# Create reports

There are multiple ways of creating or updating reports with SLiCAP:

1. Use the functions from the SLiCAPhtml module to create a web site with text, tables, typesetted equations, and figures.

2. Write your report in LaTeX and use functions from the SLiCAPlatex module to update your report with design data.

3. Write your report in Sphinx and use functions from the SLiCAPrst module to update your report with design data.